@@ -8,12 +8,13 @@ BEGIN {  # do the right thing for threads?
 }
 
 package Event;
+require 5.6.0;  #maybe
 use base 'Exporter';
 use Carp;
 eval { require Carp::Heavy; };  # work around perl_call_pv bug XXX
 use vars qw($VERSION @EXPORT_OK
 	    $API $DebugLevel $Eval $DIED $Now);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 # If we inherit DynaLoader then we inherit AutoLoader; Bletch!
 require DynaLoader;
@@ -194,6 +195,10 @@ package Event::Event::Io;
 use vars qw(@ISA);
 @ISA = 'Event::Event';
 
+package Event::Event::Dataful;
+use vars qw(@ISA);
+@ISA = 'Event::Event';
+
 package Event;
 require Event::Watcher;
 _load_watcher($_) for qw(idle io signal timer var);
